import customtkinter as ctk
import requests
from PIL import Image, ImageTk
from tkinter import messagebox
import io

SHOPPING = "#00c1ff"


def dashboard_frame(parent, switch_func, API_URL, token):
    # Main container frame
    frame = ctk.CTkFrame(parent, fg_color="transparent")

    # ------------- HEADER (Top Bar) -------------
    header_frame = ctk.CTkFrame(frame, fg_color=SHOPPING)
    header_frame.place(relx=0, rely=0, relwidth=1, relheight=0.1)

    # App Logo (Left)
    logo_label = ctk.CTkLabel(
        header_frame,
        text="Shopping App",
        text_color="white",
        font=("Helvetica", 20, "bold"),
    )
    logo_label.place(relx=0.01, rely=0.1, relwidth=0.15, relheight=0.8)

    # Search bar (Center)
    search_entry = ctk.CTkEntry(
        header_frame, placeholder_text="Search in Shop...", height=30
    )
    search_entry.place(relx=0.25, rely=0.25, relwidth=0.45, relheight=0.5)

    def perform_search():
        """Call an endpoint to search products by keyword."""
        keyword = search_entry.get().strip()
        if not keyword:
            messagebox.showinfo("Info", "Please enter a search keyword.")
            return
        try:
            headers = {"Authorization": f"Bearer {token}"}
            resp = requests.get(f"{API_URL}/product?search={keyword}", headers=headers)
            if resp.status_code == 200:
                products = resp.json()
                display_products(products, bottom_products_frame)
            else:
                messagebox.showerror("Error", "Failed to fetch search results.")
        except Exception as e:
            messagebox.showerror("Error", f"Request error: {e}")

    # Search button
    search_button = ctk.CTkButton(
        header_frame,
        text="Search",
        fg_color="white",
        text_color="black",
        command=perform_search,
    )
    search_button.place(relx=0.71, rely=0.25, relwidth=0.08, relheight=0.5)

    # ------------- MIDDLE (Featured/Top Shops) -------------
    middle_frame = ctk.CTkFrame(frame, fg_color="transparent")
    middle_frame.place(relx=0, rely=0.1, relwidth=1, relheight=0.25)

    # Section Title
    featured_label = ctk.CTkLabel(
        middle_frame, text="TOP SHOP", font=("Helvetica", 16, "bold")
    )
    featured_label.pack(pady=5)

    # A frame to hold the featured shops
    top_shops_frame = ctk.CTkFrame(middle_frame, fg_color="transparent")
    top_shops_frame.pack(fill="both", expand=True, padx=10, pady=5)

    def display_shops(shops, container):
        """Given a list of shop dicts, display them in the given container."""
        # Clear old widgets
        for widget in container.winfo_children():
            widget.destroy()

        if not shops:
            ctk.CTkLabel(container, text="No shops found.").pack(pady=10)
            return

        # Display shops in a vertical list
        for shop in shops:
            sframe = ctk.CTkFrame(container, corner_radius=5, fg_color="#2b2b2b")
            sframe.pack(fill="x", padx=5, pady=5)

            # Shop image/logo on left
            image_label = ctk.CTkLabel(sframe, text="")
            image_label.pack(side="left", padx=5, pady=5)

            # Load shop logo if available (assumes key "logo_url")
            logo_url = shop.get("logo_url")
            if logo_url:
                try:
                    resp = requests.get(logo_url)
                    if resp.status_code == 200:
                        pil_img = Image.open(io.BytesIO(resp.content)).resize((50, 50))
                        tk_img = ImageTk.PhotoImage(pil_img)
                        image_label.configure(image=tk_img, text="")
                        image_label.image = tk_img
                except Exception as e:
                    print(f"Shop image error: {e}")

            # Shop info on right
            info_frame = ctk.CTkFrame(sframe, fg_color="transparent")
            info_frame.pack(side="left", fill="both", expand=True, padx=10)

            ctk.CTkLabel(
                info_frame,
                text=shop.get("name", "No Name"),
                font=("Helvetica", 13, "bold"),
            ).pack(anchor="w")
            # Optionally add more shop details, for example a rating if available:
            if shop.get("rating"):
                ctk.CTkLabel(info_frame, text=f"Rating: {shop['rating']}").pack(
                    anchor="w"
                )

    # ------------- BOTTOM (Recommendations - Products) -------------
    bottom_frame = ctk.CTkFrame(frame, fg_color="transparent")
    bottom_frame.place(relx=0, rely=0.35, relwidth=1, relheight=0.65)

    # Section Title
    recommend_label = ctk.CTkLabel(
        bottom_frame, text="TODAY'S RECOMMENDATIONS", font=("Helvetica", 16, "bold")
    )
    recommend_label.pack(pady=5)

    bottom_products_frame = ctk.CTkFrame(bottom_frame, fg_color="transparent")
    bottom_products_frame.pack(fill="both", expand=True, padx=10, pady=5)

    def display_products(products, container):
        """Given a list of product dicts, display them in the given container."""
        # Clear old widgets
        for widget in container.winfo_children():
            widget.destroy()

        if not products:
            ctk.CTkLabel(container, text="No products found.").pack(pady=10)
            return

        # Display products in a vertical list
        for product in products:
            pframe = ctk.CTkFrame(container, corner_radius=5, fg_color="#2b2b2b")
            pframe.pack(fill="x", padx=5, pady=5)

            # Product image on left
            image_label = ctk.CTkLabel(pframe, text="")
            image_label.pack(side="left", padx=5, pady=5)

            # Load first image if available
            if product.get("images"):
                try:
                    img_url = product["images"][0]["image_url"]
                    resp = requests.get(img_url)
                    if resp.status_code == 200:
                        pil_img = Image.open(io.BytesIO(resp.content)).resize((50, 50))
                        tk_img = ImageTk.PhotoImage(pil_img)
                        image_label.configure(image=tk_img, text="")
                        image_label.image = tk_img
                except Exception as e:
                    print(f"Product image error: {e}")

            # Product info on right
            info_frame = ctk.CTkFrame(pframe, fg_color="transparent")
            info_frame.pack(side="left", fill="both", expand=True, padx=10)

            ctk.CTkLabel(
                info_frame,
                text=product.get("name", "No Name"),
                font=("Helvetica", 13, "bold"),
            ).pack(anchor="w")
            price = product.get("price", 0.0)
            ctk.CTkLabel(info_frame, text=f"Price: {price:.2f}").pack(anchor="w")

    def fetch_featured_shops():
        """Fetch some 'featured' or 'top' shops for the middle section."""
        headers = {"Authorization": f"Bearer {token}"}
        try:
            resp = requests.get(f"{API_URL}/shops/list", headers=headers)
            if resp.status_code == 200:
                shops = resp.json()
                # Slice the list to display only a handful of top shops
                display_shops(shops[:5], top_shops_frame)
            else:
                messagebox.showerror("Error", "Failed to fetch featured shops.")
        except Exception as e:
            messagebox.showerror("Error", f"Request error: {e}")

    def fetch_recommendations():
        """Fetch recommended products for the bottom section."""
        headers = {"Authorization": f"Bearer {token}"}
        try:
            resp = requests.get(f"{API_URL}/product/list", headers=headers)
            if resp.status_code == 200:
                products = resp.json()
                display_products(products, bottom_products_frame)
            else:
                messagebox.showerror("Error", "Failed to fetch recommended products.")
        except Exception as e:
            messagebox.showerror("Error", f"Request error: {e}")

    # Load data on start
    fetch_featured_shops()
    fetch_recommendations()

    return frame
